==> tine20-humanresources_2019.12.5.tar.bz2: HumanResources/js/HumanResources-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "Você não tem direitos de Admin em Recursos Humanos"

, "Wage types"
: ""

, "Free time types"
: ""

, "Working time scheme, Working time schemes"
: [
  ""
 ,""

]
, "Book as vacation"
: ""

, "Sickness"
: "Doença"

, "Sickness Days"
: ""

, "Vacation"
: "Férias"

, "Vacation Days"
: "Dias de Férias"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: ""

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""
 ,""

]
, "Template"
: ""

, "Individual"
: ""

, "Shared"
: ""

, "Edit {0} for {1} - {2}"
: ""

, "Extra free time, Extra free times"
: [
  ""
 ,""

]
, "Summary"
: ""

, "Free Times"
: ""

, "Possible vaction days"
: ""

, "Remaining vaction days"
: ""

, "Taken vaction days"
: ""

, "Expired vaction days"
: ""

, "Rebooked vaction days"
: ""

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: ""

, "Hours to work"
: ""

, "Days to work after vacation and sickness"
: ""

, "Hours to work after vacation and sickness"
: ""

, "Miscellaneous"
: ""

, "Description"
: "Descrição"

, "Employee, Employees"
: [
  "Funcionário"
 ,"Funcionários"

]
, "Calculate all Reports"
: ""

, "Recalculate"
: ""

, "Cancel"
: "Cancelar"

, "OK"
: "OK"

, "Please use the following format: MM-DD"
: ""

, "Calendar"
: "Calendário"

, "Calendars"
: "Calendários"

, "Vacation expires"
: ""

, "Book remaining vacation"
: ""

, "Year"
: "Ano"

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: ""

, "Booking has been successfull!"
: ""

, "The remaining vacation days of the selected accounts have been booked successfully!"
: ""

, "CostCenter, CostCenters"
: [
  ""
 ,""

]
, "Cost Center, Cost Centers"
: [
  ""
 ,"Centro de Custo"

]
, "Startdate"
: "Hora de início"

, "Contract, Contracts"
: [
  "Contrato"
 ,"Contratos"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: ""

, "Working Time Rules"
: ""

, "Start Date"
: "Data de Início"

, "End Date"
: "Data Final"

, "Feast Calendar"
: "Calendário Festivo"

, "Vacation days of one calendar year"
: ""

, "Working Time Schema"
: ""

, "Working Hours per week"
: "Horas de Trabalho por Semana"

, "Mon."
: "Segunda-feira"

, "Tue."
: "Terça-feira"

, "Wed."
: "Quarta-feira"

, "Thu."
: "Quinta-feira"

, "Fri."
: "Sexta-feira"

, "Sat."
: "Sábado"

, "Sun."
: "Domingo"

, "Edit {0} \"{1}\""
: ""

, "Edit {0} for {1}"
: ""

, "Add {0} for {1}"
: ""

, "You have to select at least one day to save this sickness entry."
: ""

, "You have to select at least one day to save this vacation entry."
: ""

, "No day selected"
: ""

, "Personal account, Personal accounts"
: [
  ""
 ,""

]
, "Status"
: "Situação"

, "Remaining"
: ""

, "Select Days"
: "Selecione os dias"

, "Enter description"
: "Descrição"

, "Account is disabled or deleted!"
: ""

, "Division"
: "Divisão"

, "Health Insurance"
: "Seguro Saúde"

, "Apply contact data on form"
: "Informar dados do contato no formulário"

, "Salutation"
: "Saudação"

, "Personal Information"
: "Dados Pessoais"

, "Country"
: "País"

, "Birthday"
: "Aniversário"

, "Internal Information"
: "Informaçãok Interna"

, "Banking Information"
: "Informação sobre o Banco"

, "Type"
: "Tipo"

, "Template (individual working time schemas are created for each contract)"
: ""

, "Shared (this working time schemas can be shared among contracts)"
: ""

, "Days"
: ""

, "Expiration date"
: ""

, "WK"
: "WK"

, "Loading calendar data..."
: "Carregando dados do calendário..."

, "Year can not be changed"
: ""

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: ""

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: "Desculpado"

, "Unexcused"
: "Não justificada"

, "Currently employed"
: "Empregado atual"

, "Employees which are currently employed"
: "Funcionários que estão empregados atualmente"

, "All employees"
: ""

, "All available employees"
: ""

, "Payed"
: ""

, "Not payed"
: ""

, "Currently employed employees"
: ""

, "All accounts"
: ""

, "All available accounts"
: ""

, "Full-time 40 hours"
: ""

, "Full-time 37.5 hours"
: ""

, "Part-time 20 hours"
: ""

, "Default wage type"
: ""

, "Salary"
: ""

, "Business trip"
: ""

, "Sunday bonus"
: ""

, "Feast day"
: ""

, "Feast day bonus"
: ""

, "Overtime"
: ""

, "Overtime bonus"
: ""

, "Late shift bonus"
: ""

, "Night bonus"
: ""

, "Break"
: ""

, "Stand by"
: ""

, "Unpaid"
: ""

, "[S] Sickness"
: ""

, "[D] Visit doctor"
: ""

, "[V] Vacation"
: ""

, "[BT] Business trip"
: ""

, "[FT] Flex time"
: ""

, "[BK] Break"
: ""

, "[T] Training"
: ""

, "Freetime Type"
: "Tipos de Afastamento"

, "Possible free time definitions"
: "Definições de tempo livre possíveis"

, "Vacation Status"
: "Situação das férias"

, "Possible vacation status definitions"
: "Definições de situações de férias possíveis"

, "Requested"
: "Solicitado"

, "In process"
: "Processando"

, "Accepted"
: "Aceito"

, "Declined"
: "Recusado"

, "Sickness Status"
: "Situação da doença"

, "Possible sickness status definitions"
: "Definições de doenças possíveis"

, "Default Feast Calendar"
: "Calendário de Festas Padrão"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "Aqui você pode definir o calendário de festas padrão usado para cadastrar os dias de festa e outros dias livre no selecionador de datas"

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: ""

, "Possible extra free time definitions"
: ""

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: ""

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "No valid contract for this date"
: ""

, "unexpected error: "
: ""

, "daily wt reports can't be created"
: ""

, "It is not allowed to update a cleared report"
: ""

, "monthly wt reports can't be created"
: ""

, "previous months need to be cleared first"
: ""

, "following months need to be uncleared first"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""
 ,""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Corrected Evaluation Start Time"
: ""

, "Corrected Evaluation End Time"
: ""

, "Target Working Time"
: ""

, "Target Working Time Correction"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Working Times"
: ""

, "Actual Working Time"
: ""

, "Working Time Correction"
: ""

, "Total Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Calculation Error"
: ""

, "Monthly Working Time Report, Monthly Working Time Reports"
: [
  ""
 ,""

]
, "Month"
: ""

, "Daily Working Time Reports"
: ""

, "Working Time Balance Previous Month"
: ""

, "Total Working Time Balance"
: ""

, "Wage type, Wage types"
: [
  ""
 ,""

]
, "Abbreviation"
: ""

, "Name"
: ""

, "System"
: ""

, "Factor (%)"
: ""

, "Additional Wage"
: ""

, "Quick search"
: "Busca rápida"

, "Extra free times"
: ""

, "Start time"
: ""

, "Break Time, Break Times"
: [
  ""
 ,""

]
, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
: ""

, "Time worked"
: ""

, "Break time"
: ""

, "Work Time Limit, Work Time Limits"
: [
  ""
 ,""

]
, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
: ""

, "Absence reason, Absence reasons"
: [
  ""
 ,""

]
, "Allow Booking"
: ""

, "Allow Planning"
: ""

, "Enable Freetime Timetracking"
: ""

, "Timeaccount"
: ""

, "Free Time, Free Times"
: [
  "Afastamento"
 ,"Afastamentos"

]
, "Account"
: "Conta"

, "First Day"
: ""

, "Last Day"
: ""

, "Days Count"
: ""

, "Free Days"
: ""

, "Private Information"
: "Informação Particular"

, "Is employed"
: ""

, "Number"
: "Número"

, "Transponder Id"
: ""

, "Germany"
: ""

, "Locality"
: "Cidade"

, "Postalcode"
: "CEP"

, "Region"
: "Municipio"

, "Street"
: "Endereço"

, "Street 2"
: ""

, "E-Mail"
: "eMail"

, "Telephone Number"
: "Telefone"

, "Cell Phone Number"
: "Celular"

, "Title"
: "Título"

, "Last Name"
: "Sobrenome"

, "First Name"
: "Nome"

, "Employee name"
: "Nome do Funcionário"

, "Account Holder"
: "Proprietário da Conta"

, "Account Number"
: "Número da Conta"

, "Bank Name"
: "Nome do Banco"

, "Code Number"
: "Número do Código"

, "Employment begin"
: "Início do emprego"

, "Employment end"
: "Fim do emprego"

, "Supervisor"
: "Supervisor"

, "Profession"
: "Profissão"

, "Position"
: ""

, "Contracts"
: ""

, "Cost Centers"
: ""

, "Free Day, Free Days"
: [
  "Afastamento"
 ,"Afastamentos"

]
, "No contract could be found."
: "Nenhum contrato encontrado"

, "Please create a contract for this employee!"
: "Por favor, crie um contrato para este funcionário"

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: ""

, "Not allowed!"
: ""

, "It's only allowed to book remaining vacation days from years in the past!"
: ""

, "Contracts overlap"
: ""

, "The contracts must not overlap!"
: ""

, "No or no valid year given"
: ""

, "Please use a valid year!"
: ""

, "No current contract!"
: ""

, "A current contract could not be found!"
: ""

, "Contract not editable"
: ""

, "You are not allowed to change the record if a vacation has been booked already!"
: ""

, "No personal account found"
: ""

, "An existing personal account could not be found. Please create one!"
: ""

, "edit private employee data"
: "Editar informações particulares do empregado"

, "Edit birthday, account data and other private information of employee records"
: "Editar Data de Nascimento, dados da conta e informações particulares do empregado"


, "Working time scheme"
: ""

, "Human Resources"
: ""

, "Extra free time"
: ""

, "Employee"
: "Funcionário"

, "CostCenter"
: ""

, "Cost Center"
: ""

, "Contract"
: "Contrato"

, "Personal account"
: ""

, "Daily Working Time Report"
: ""

, "Monthly Working Time Report"
: ""

, "Wage type"
: ""

, "Break Time"
: ""

, "Work Time Limit"
: ""

, "Absence reason"
: ""

, "Free Time"
: "Afastamento"

, "Free Day"
: "Afastamento"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-humanresources_2020.08.8.tar.bz2: HumanResources/js/HumanResources-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "Você não tem direitos de Admin em Recursos Humanos"

, "Working time model"
: ""

, "Book as vacation"
: ""

, "Sickness"
: "Doença"

, "Sickness Days"
: ""

, "Vacation"
: "Férias"

, "Vacation Days"
: "Dias de Férias"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: ""

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""
 ,""

]
, "Title"
: "Título"

, "Work Start"
: ""

, "Work End"
: ""

, "Edit {0} for {1} - {2}"
: ""

, "Extra free time, Extra free times"
: [
  ""
 ,""

]
, "Summary"
: ""

, "Free Times"
: ""

, "Possible vaction days"
: ""

, "Remaining vaction days"
: ""

, "Taken vaction days"
: ""

, "Expired vaction days"
: ""

, "Rebooked vaction days"
: ""

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: ""

, "Hours to work"
: ""

, "Days to work after vacation and sickness"
: ""

, "Hours to work after vacation and sickness"
: ""

, "Miscellaneous"
: ""

, "Description"
: "Descrição"

, "Working time Model"
: ""

, "Work start"
: ""

, "not set"
: ""

, "Work end"
: ""

, "Working Hours per week"
: "Horas de Trabalho por Semana"

, "Mon."
: "Segunda-feira"

, "Tue."
: "Terça-feira"

, "Wed."
: "Quarta-feira"

, "Thu."
: "Quinta-feira"

, "Fri."
: "Sexta-feira"

, "Sat."
: "Sábado"

, "Sun."
: "Domingo"

, "Employee, Employees"
: [
  "Funcionário"
 ,"Funcionários"

]
, "Cancel"
: "Cancelar"

, "OK"
: "OK"

, "Please use the following format: MM-DD"
: ""

, "Calendar"
: "Calendário"

, "Calendars"
: "Calendários"

, "Vacation expires"
: ""

, "Breaks"
: ""

, "Hours"
: ""

, "Break duration"
: ""

, "Book remaining vacation"
: ""

, "Year"
: "Ano"

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: ""

, "Booking has been successfull!"
: ""

, "The remaining vacation days of the selected accounts have been booked successfully!"
: ""

, "CostCenter, CostCenters"
: [
  ""
 ,""

]
, "Cost Center, Cost Centers"
: [
  ""
 ,"Centro de Custo"

]
, "Startdate"
: "Hora de início"

, "Contract, Contracts"
: [
  "Contrato"
 ,"Contratos"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: ""

, "Start Date"
: "Data de Início"

, "End Date"
: "Data Final"

, "Feast Calendar"
: "Calendário Festivo"

, "Choose the template"
: "Escolha o modelo"

, "Vacation days of one calendar year"
: ""

, "Edit {0} \"{1}\""
: ""

, "Edit {0} for {1}"
: ""

, "Add {0} for {1}"
: ""

, "You have to select at least one day to save this sickness entry."
: ""

, "You have to select at least one day to save this vacation entry."
: ""

, "No day selected"
: ""

, "Personal account, Personal accounts"
: [
  ""
 ,""

]
, "Status"
: "Situação"

, "Remaining"
: ""

, "Select Days"
: "Selecione os dias"

, "Enter description"
: "Descrição"

, "Account is disabled or deleted!"
: ""

, "Division"
: "Divisão"

, "Health Insurance"
: "Seguro Saúde"

, "Apply contact data on form"
: "Informar dados do contato no formulário"

, "Salutation"
: "Saudação"

, "Personal Information"
: "Dados Pessoais"

, "Country"
: "País"

, "Birthday"
: "Aniversário"

, "Internal Information"
: "Informaçãok Interna"

, "Banking Information"
: "Informação sobre o Banco"

, "Days"
: ""

, "Type"
: "Tipo"

, "Expiration date"
: ""

, "WK"
: "WK"

, "Loading calendar data..."
: "Carregando dados do calendário..."

, "Year can not be changed"
: ""

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: ""

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: "Desculpado"

, "Unexcused"
: "Não justificada"

, "Currently employed"
: "Empregado atual"

, "Employees which are currently employed"
: "Funcionários que estão empregados atualmente"

, "All employees"
: ""

, "All available employees"
: ""

, "Payed"
: ""

, "Not payed"
: ""

, "Currently employed employees"
: ""

, "All accounts"
: ""

, "All available accounts"
: ""

, "Full-time 40 hours"
: ""

, "Full-time 37.5 hours"
: ""

, "Part-time 20 hours"
: ""

, "Freetime Type"
: "Tipos de Afastamento"

, "Possible free time definitions"
: "Definições de tempo livre possíveis"

, "Vacation Status"
: "Situação das férias"

, "Possible vacation status definitions"
: "Definições de situações de férias possíveis"

, "Requested"
: "Solicitado"

, "In process"
: "Processando"

, "Accepted"
: "Aceito"

, "Declined"
: "Recusado"

, "Sickness Status"
: "Situação da doença"

, "Possible sickness status definitions"
: "Definições de doenças possíveis"

, "Default Feast Calendar"
: "Calendário de Festas Padrão"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "Aqui você pode definir o calendário de festas padrão usado para cadastrar os dias de festa e outros dias livre no selecionador de datas"

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: ""

, "Possible extra free time definitions"
: ""

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: ""

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""
 ,""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Paid Absence Time"
: ""

, "Unpaid Absence Time"
: ""

, "Absence"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Feast Time"
: ""

, "Break Time"
: ""

, "Sickness Time"
: ""

, "Working Time Correction"
: ""

, "Actual Working Time"
: ""

, "Target Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Cleared in"
: ""

, "Working time, Working times"
: [
  ""
 ,""

]
, "Quick search"
: "Busca rápida"

, "Extra free times"
: ""

, "Free Time, Free Times"
: [
  "Afastamento"
 ,"Afastamentos"

]
, "Account"
: "Conta"

, "First Day"
: ""

, "Last Day"
: ""

, "Days Count"
: ""

, "Free Days"
: ""

, "Private Information"
: "Informação Particular"

, "Is employed"
: ""

, "Number"
: "Número"

, "Badge Id"
: ""

, "Germany"
: ""

, "Locality"
: "Cidade"

, "Postalcode"
: "CEP"

, "Region"
: "Municipio"

, "Street"
: "Endereço"

, "Street 2"
: ""

, "E-Mail"
: "eMail"

, "Telephone Number"
: "Telefone"

, "Cell Phone Number"
: "Celular"

, "Last Name"
: "Sobrenome"

, "First Name"
: "Nome"

, "Employee name"
: "Nome do Funcionário"

, "Account Holder"
: "Proprietário da Conta"

, "Account Number"
: "Número da Conta"

, "Bank Name"
: "Nome do Banco"

, "Code Number"
: "Número do Código"

, "Employment begin"
: "Início do emprego"

, "Employment end"
: "Fim do emprego"

, "Supervisor"
: "Supervisor"

, "Profession"
: "Profissão"

, "Position"
: ""

, "Contracts"
: ""

, "Cost Centers"
: ""

, "Free Day, Free Days"
: [
  "Afastamento"
 ,"Afastamentos"

]
, "Break, Breaks"
: [
  ""
 ,""

]
, "Workingtime"
: ""

, "No contract could be found."
: "Nenhum contrato encontrado"

, "Please create a contract for this employee!"
: "Por favor, crie um contrato para este funcionário"

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: ""

, "Not allowed!"
: ""

, "It's only allowed to book remaining vacation days from years in the past!"
: ""

, "Contracts overlap"
: ""

, "The contracts must not overlap!"
: ""

, "No or no valid year given"
: ""

, "Please use a valid year!"
: ""

, "No current contract!"
: ""

, "A current contract could not be found!"
: ""

, "Contract not editable"
: ""

, "You are not allowed to change the record if a vacation has been booked already!"
: ""

, "No personal account found"
: ""

, "An existing personal account could not be found. Please create one!"
: ""

, "edit private employee data"
: "Editar informações particulares do empregado"

, "Edit birthday, account data and other private information of employee records"
: "Editar Data de Nascimento, dados da conta e informações particulares do empregado"

, "Public Holiday Calendar"
: ""

, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
: ""

, "Public Holidays"
: ""

, "Badge ID"
: ""

, "Human Resources"
: ""

, "Extra free time"
: ""

, "Employee"
: "Funcionário"

, "CostCenter"
: ""

, "Cost Center"
: ""

, "Contract"
: "Contrato"

, "Personal account"
: ""

, "Daily Working Time Report"
: ""

, "Working time"
: ""

, "Free Time"
: "Afastamento"

, "Free Day"
: "Afastamento"

, "Break"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
